@@ -1,5 +1,5 @@
 from youtubesearchpython.__future__.search import Search, VideosSearch, ChannelsSearch, PlaylistsSearch, CustomSearch
-from youtubesearchpython.__future__.extras import Video, Playlist, Suggestions
+from youtubesearchpython.__future__.extras import Video, Playlist, Suggestions, Hashtag
 from youtubesearchpython.__future__.streamurlfetcher import StreamURLFetcher
 from youtubesearchpython.__future__.internal.constants import *
 
