@@ -141,7 +141,9 @@ class PlaylistInternal:
             self.__parseSource()
             self.__getComponents()
             if resultMode == ResultMode.json:
-                self.result = json.dumps(self.result, indent=4)
+                self.result = json.dumps(self.playlistComponent, indent=4)
+            else:
+                self.result = self.playlistComponent
         else:
             raise Exception('ERROR: Invalid status code.')
 
@@ -153,6 +155,8 @@ class PlaylistInternal:
                 self.__getNextComponents()
                 if self.resultMode == ResultMode.json:
                     self.result = json.dumps(self.playlistComponent, indent=4)
+                else:
+                    self.result = self.playlistComponent
             else:
                 raise Exception('ERROR: Invalid status code.')
 
@@ -168,6 +172,8 @@ class PlaylistInternal:
             r = self.response[startpoint:endpoint]
             r = r.replace(";</script>", "")
             self.response = r
+            print(startpoint)
+            print(endpoint)
 
     def __makeRequest(self, playlistLink: str) -> int:
         playlistLink.strip('/')
@@ -201,9 +207,8 @@ class PlaylistInternal:
             },
         )
         try:
-            response = urlopen(request)
-            self.response = response.read(timeout=self.timeout).decode('utf_8')
-            print(self.response)
+            response = urlopen(request, timeout=self.timeout)
+            self.response = response.read().decode('utf_8')
             return response.getcode()
         except:
             raise Exception('ERROR: Could not make request.')
@@ -253,18 +258,19 @@ class PlaylistInternal:
                 "channel": {
                     "id": self.__getValue(channelrenderer, ["title", "runs", 0, "navigationEndpoint", "browseEndpoint", "browseId"]),
                     "name": self.__getValue(channelrenderer, ["title", "runs", 0, "text"]),
-                    "link": "https_//www.youtube.com" + self.__getValue(channelrenderer, ["title", "runs", 0, "navigationEndpoint", "browseEndpoint", "canonicalBaseUrl"]),
+                    "link": "https://www.youtube.com" + self.__getValue(channelrenderer, ["title", "runs", 0, "navigationEndpoint", "browseEndpoint", "canonicalBaseUrl"]),
                     "thumbnails": self.__getValue(channelrenderer, ["thumbnail", "thumbnails"]),
                 }
             },
             'videos': videos,
         }
         if self.componentMode == "getInfo":
-            self.result = playlistElement["info"]
+            self.playlistComponent = playlistElement["info"]
         elif self.componentMode == "getVideos":
-            self.result = {"videos": videos}
+            self.playlistComponent = {"videos": videos}
         else:
-            self.result = playlistElement
+            self.playlistComponent = playlistElement
+        self.continuationKey = self.__getValue(videorenderer, [-1, "continuationItemRenderer", "continuationEndpoint", "continuationCommand", "token"])
 
     def __getNextComponents(self) -> None:
         self.continuationKey = None
@@ -280,11 +286,13 @@ class PlaylistInternal:
                     'id': self.__getValue(videoElement, [playlistVideoKey, 'videoId']),
                     'title': self.__getValue(videoElement, [playlistVideoKey, 'title', 'runs', 0, 'text']),
                     'thumbnails': self.__getValue(videoElement, [playlistVideoKey, 'thumbnail', 'thumbnails']),
+                    'link': "https://www.youtube.com" + self.__getValue(videoElement, [playlistVideoKey, "navigationEndpoint", "commandMetadata", "webCommandMetadata", "url"]),
                     'channel': {
                         'name': self.__getValue(videoElement, [playlistVideoKey, 'shortBylineText', 'runs', 0, 'text']),
                         'id': self.__getValue(videoElement,
                                               [playlistVideoKey, 'shortBylineText', 'runs', 0, 'navigationEndpoint',
                                                'browseEndpoint', 'browseId']),
+                        "link": "https://www.youtube.com" + self.__getValue(videoElement, [playlistVideoKey, "shortBylineText", "runs", 0, "navigationEndpoint", "browseEndpoint", "canonicalBaseUrl"])
                     },
                     'duration': self.__getValue(videoElement, [playlistVideoKey, 'lengthText', 'simpleText']),
                     'accessibility': {
@@ -298,9 +306,8 @@ class PlaylistInternal:
                 playlistComponent['videos'].append(
                     videoComponent
                 )
-            if continuationItemKey in videoElement.keys():
-                self.continuationKey = self.__getValue(videoElement, continuationKeyPath)
-        self.playlistComponent['videos'].extend(playlistComponent['videos'])
+            self.continuationKey = self.__getValue(videoElement, continuationKeyPath)
+        self.playlistComponent["videos"].extend(playlistComponent['videos'])
 
     def __getPlaylistComponent(self, element: dict, mode: str) -> dict:
         playlistComponent = {}
