@@ -1,5 +1,5 @@
 from youtubesearchpython.internal.constants import *
-from youtubesearchpython.internal.search import SearchInternal
+from youtubesearchpython.internal.search import SearchInternal, ChannelSearchInternal
 
 
 class Search(SearchInternal):
@@ -67,9 +67,9 @@ class Search(SearchInternal):
             ]
         }
     '''
-    def __init__(self, query: str, limit: int = 20, language: str = 'en', region: str = 'US'):
+    def __init__(self, query: str, limit: int = 20, language: str = 'en', region: str = 'US', timeout: int = None):
         self.searchMode = (True, True, True)
-        super().__init__(query, limit, language, region, None)
+        super().__init__(query, limit, language, region, None, timeout)
         self._getComponents(*self.searchMode)
 
 class VideosSearch(SearchInternal):
@@ -137,9 +137,9 @@ class VideosSearch(SearchInternal):
             ]
         }
     '''
-    def __init__(self, query: str, limit: int = 20, language: str = 'en', region: str = 'US'):
+    def __init__(self, query: str, limit: int = 20, language: str = 'en', region: str = 'US', timeout: int = None):
         self.searchMode = (True, False, False)
-        super().__init__(query, limit, language, region, SearchMode.videos)
+        super().__init__(query, limit, language, region, SearchMode.videos, timeout)
         self._getComponents(*self.searchMode)
 
 
@@ -183,9 +183,9 @@ class ChannelsSearch(SearchInternal):
             ]
         }
     '''
-    def __init__(self, query: str, limit: int = 20, language: str = 'en', region: str = 'US'):
+    def __init__(self, query: str, limit: int = 20, language: str = 'en', region: str = 'US', timeout: int = None):
         self.searchMode = (False, True, False)
-        super().__init__(query, limit, language, region, SearchMode.channels)
+        super().__init__(query, limit, language, region, SearchMode.channels, timeout)
         self._getComponents(*self.searchMode)
 
 
@@ -242,11 +242,86 @@ class PlaylistsSearch(SearchInternal):
             ]
         }
     '''
-    def __init__(self, query: str, limit: int = 20, language: str = 'en', region: str = 'US'):
+    def __init__(self, query: str, limit: int = 20, language: str = 'en', region: str = 'US', timeout: int = None):
         self.searchMode = (False, False, True)
-        super().__init__(query, limit, language, region, SearchMode.playlists)
+        super().__init__(query, limit, language, region, SearchMode.playlists, timeout)
         self._getComponents(*self.searchMode)
 
+class ChannelSearch(ChannelSearchInternal):
+    '''Searches for videos in specific channel in YouTube.
+
+    Args:
+        query (str): Sets the search query.
+        browseId (str): Channel ID
+        language (str, optional): Sets the result language. Defaults to 'en'.
+        region (str, optional): Sets the result region. Defaults to 'US'.
+
+    Examples:
+        Calling `result` method gives the search result.
+
+        >>> search = ChannelSearch('Watermelon Sugar', "UCZFWPqqPkFlNwIxcpsLOwew")
+        >>> print(search.result())
+        {
+            "result": [
+                {
+                    "id": "WMcIfZuRuU8",
+                    "thumbnails": {
+                        "normal": [
+                            {
+                                "url": "https://i.ytimg.com/vi/WMcIfZuRuU8/hqdefault.jpg?sqp=-oaymwEbCKgBEF5IVfKriqkDDggBFQAAiEIYAXABwAEG&rs=AOn4CLClFg6C1r5NfTQy7TYUq6X5qHUmPA",
+                                "width": 168,
+                                "height": 94
+                            },
+                            {
+                                "url": "https://i.ytimg.com/vi/WMcIfZuRuU8/hqdefault.jpg?sqp=-oaymwEbCMQBEG5IVfKriqkDDggBFQAAiEIYAXABwAEG&rs=AOn4CLAoOyftwY0jLV4geWb5hejULYp3Zw",
+                                "width": 196,
+                                "height": 110
+                            },
+                            {
+                                "url": "https://i.ytimg.com/vi/WMcIfZuRuU8/hqdefault.jpg?sqp=-oaymwEcCPYBEIoBSFXyq4qpAw4IARUAAIhCGAFwAcABBg==&rs=AOn4CLCdqkhn7JDwLvRtTNx3jq-olz7k-Q",
+                                "width": 246,
+                                "height": 138
+                            },
+                            {
+                                "url": "https://i.ytimg.com/vi/WMcIfZuRuU8/hqdefault.jpg?sqp=-oaymwEcCNACELwBSFXyq4qpAw4IARUAAIhCGAFwAcABBg==&rs=AOn4CLAhYedsqBFKI0Ra2qzIv9cVoZhfKQ",
+                                "width": 336,
+                                "height": 188
+                            }
+                        ],
+                        "rich": null
+                    },
+                    "title": "Harry Styles \u2013 Watermelon Sugar (Lost Tour Visual)",
+                    "descriptionSnippet": "This video is dedicated to touching.\nListen to Harry Styles\u2019 new album \u2018Fine Line\u2019 now: https://HStyles.lnk.to/FineLineAY \n\nFollow Harry Styles:\nFacebook: https://HarryStyles.lnk.to/followFI...",
+                    "uri": "/watch?v=WMcIfZuRuU8",
+                    "views": {
+                        "precise": "3,888,287 views",
+                        "simple": "3.8M views",
+                        "approximate": "3.8 million views"
+                    },
+                    "duration": {
+                        "simpleText": "2:55",
+                        "text": "2 minutes, 55 seconds"
+                    },
+                    "published": "10 months ago",
+                    "channel": {
+                        "name": "Harry Styles",
+                        "thumbnails": [
+                            {
+                                "url": "https://yt3.ggpht.com/ytc/AAUvwnhR81ocC_KalYEk5ItnJcfMBqaiIpuM1B0lJyg4Rw=s88-c-k-c0x00ffffff-no-rj",
+                                "width": 68,
+                                "height": 68
+                            }
+                        ]
+                    },
+                    "type": "video"
+                },
+            ]
+        }
+    '''
+
+    def __init__(self, query: str, browseId: str, language: str = 'en', region: str = 'US', searchPreferences: str = "EgZzZWFyY2g%3D", timeout: int = None):
+        super().__init__(query, language, region, searchPreferences, browseId, timeout)
+
 class CustomSearch(SearchInternal):
     '''Performs custom search in YouTube with search filters or sorting orders. 
     Few of the predefined filters and sorting orders are:
@@ -323,7 +398,7 @@ class CustomSearch(SearchInternal):
             ]
         }
     '''
-    def __init__(self, query: str, searchPreferences: str, limit: int = 20, language: str = 'en', region: str = 'US'):
+    def __init__(self, query: str, searchPreferences: str, limit: int = 20, language: str = 'en', region: str = 'US', timeout: int = None):
         self.searchMode = (True, True, True)
-        super().__init__(query, limit, language, region, searchPreferences)
+        super().__init__(query, limit, language, region, searchPreferences, timeout)
         self._getComponents(*self.searchMode)
